@@ -56,7 +56,6 @@ impl Column for Command {
     column_default!(String);
 }
 
-#[cfg_attr(tarpaulin, skip)]
 #[cfg(target_os = "macos")]
 impl Column for Command {
     fn add(&mut self, proc: &ProcessInfo) {
@@ -89,7 +88,6 @@ impl Column for Command {
     column_default!(String);
 }
 
-#[cfg_attr(tarpaulin, skip)]
 #[cfg(target_os = "windows")]
 impl Column for Command {
     fn add(&mut self, proc: &ProcessInfo) {
@@ -103,12 +101,11 @@ impl Column for Command {
     column_default!(String);
 }
 
-#[cfg_attr(tarpaulin, skip)]
 #[cfg(target_os = "freebsd")]
 impl Column for Command {
     fn add(&mut self, proc: &ProcessInfo) {
         let command = if proc.curr_proc.arg.is_empty() {
-            let comm = crate::util::i8_to_cstr(proc.curr_proc.info.comm.as_ref());
+            let comm = crate::util::ptr_to_cstr(proc.curr_proc.info.comm.as_ref());
             if let Ok(comm) = comm {
                 format!("[{}]", comm.to_string_lossy())
             } else {
