@@ -67,8 +67,8 @@ impl Column for ElapsedTime {
     fn add(&mut self, proc: &ProcessInfo) {
         let starttime = proc.curr_proc.stat().starttime;
         let seconds_since_boot = starttime as f32 / *TICKS_PER_SECOND as f32;
-        let start_time =
-            self.boot_time + Duration::milliseconds((seconds_since_boot * 1000.0) as i64);
+        let start_time = self.boot_time
+            + Duration::try_milliseconds((seconds_since_boot * 1000.0) as i64).unwrap_or_default();
         let raw_content = Local::now().signed_duration_since(start_time);
         let fmt_content = format_duration(raw_content);
 
@@ -79,7 +79,6 @@ impl Column for ElapsedTime {
     column_default!(Duration);
 }
 
-#[cfg_attr(tarpaulin, skip)]
 #[cfg(target_os = "macos")]
 impl Column for ElapsedTime {
     fn add(&mut self, proc: &ProcessInfo) {
@@ -96,7 +95,6 @@ impl Column for ElapsedTime {
     column_default!(Duration);
 }
 
-#[cfg_attr(tarpaulin, skip)]
 #[cfg(target_os = "windows")]
 impl Column for ElapsedTime {
     fn add(&mut self, proc: &ProcessInfo) {
@@ -110,7 +108,6 @@ impl Column for ElapsedTime {
     column_default!(Duration);
 }
 
-#[cfg_attr(tarpaulin, skip)]
 #[cfg(target_os = "freebsd")]
 impl Column for ElapsedTime {
     fn add(&mut self, proc: &ProcessInfo) {
