@@ -1,7 +1,9 @@
 use crate::process::ProcessInfo;
+use crate::util::USERS_CACHE;
 use crate::{column_default, Column};
 use std::cmp;
 use std::collections::HashMap;
+use uzers::Groups;
 
 pub struct GroupFs {
     header: String,
@@ -29,7 +31,7 @@ impl Column for GroupFs {
     fn add(&mut self, proc: &ProcessInfo) {
         let fmt_content = if let Some(ref status) = proc.curr_status {
             let gid = status.fgid;
-            if let Some(group) = users::get_group_by_gid(gid) {
+            if let Some(group) = USERS_CACHE.with(|x| x.borrow_mut().get_group_by_gid(gid)) {
                 format!("{}", group.name().to_string_lossy())
             } else {
                 format!("{gid}")
