@@ -38,7 +38,6 @@ impl Column for MajFlt {
     column_default!(u64);
 }
 
-#[cfg_attr(tarpaulin, skip)]
 #[cfg(target_os = "macos")]
 impl Column for MajFlt {
     fn add(&mut self, proc: &ProcessInfo) {
@@ -52,7 +51,6 @@ impl Column for MajFlt {
     column_default!(u64);
 }
 
-#[cfg_attr(tarpaulin, skip)]
 #[cfg(target_os = "windows")]
 impl Column for MajFlt {
     fn add(&mut self, proc: &ProcessInfo) {
@@ -65,3 +63,16 @@ impl Column for MajFlt {
 
     column_default!(u64);
 }
+
+#[cfg(target_os = "freebsd")]
+impl Column for MajFlt {
+    fn add(&mut self, proc: &ProcessInfo) {
+        let raw_content = proc.curr_proc.info.rusage.majflt as u64;
+        let fmt_content = format!("{raw_content}");
+
+        self.fmt_contents.insert(proc.pid, fmt_content);
+        self.raw_contents.insert(proc.pid, raw_content);
+    }
+
+    column_default!(u64);
+}
