@@ -11,11 +11,10 @@ pub struct MultiSlot {
     width: usize,
 }
 
-#[cfg_attr(tarpaulin, skip)]
 impl MultiSlot {
     pub fn new() -> Self {
-        let header = String::from("");
-        let unit = String::from("");
+        let header = String::new();
+        let unit = String::new();
         MultiSlot {
             fmt_contents: HashMap::new(),
             raw_contents: HashMap::new(),
@@ -26,11 +25,10 @@ impl MultiSlot {
     }
 }
 
-#[cfg_attr(tarpaulin, skip)]
 impl Column for MultiSlot {
     fn add(&mut self, proc: &ProcessInfo) {
-        let raw_content = "".to_string();
-        let fmt_content = "".to_string();
+        let raw_content = String::new();
+        let fmt_content = String::new();
 
         self.fmt_contents.insert(proc.pid, fmt_content);
         self.raw_contents.insert(proc.pid, raw_content);
