@@ -25,6 +25,7 @@ impl Processor {
     }
 }
 
+#[cfg(any(target_os = "linux", target_os = "android"))]
 impl Column for Processor {
     fn add(&mut self, proc: &ProcessInfo) {
         let raw_content = proc.curr_proc.stat().processor.unwrap_or_default();
@@ -40,3 +41,16 @@ impl Column for Processor {
 
     column_default!(i32);
 }
+
+#[cfg(target_os = "freebsd")]
+impl Column for Processor {
+    fn add(&mut self, proc: &ProcessInfo) {
+        let raw_content = proc.curr_proc.info.lastcpu;
+        let fmt_content = format!("{raw_content}");
+
+        self.fmt_contents.insert(proc.pid, fmt_content);
+        self.raw_contents.insert(proc.pid, raw_content);
+    }
+
+    column_default!(i32);
+}
