@@ -1,7 +1,9 @@
 use crate::process::ProcessInfo;
+use crate::util::USERS_CACHE;
 use crate::{column_default, Column};
 use std::cmp;
 use std::collections::HashMap;
+use uzers::Users;
 
 const UID_NOT_SET: u32 = 0xffffffff;
 
@@ -30,7 +32,7 @@ impl UserLogin {
 impl Column for UserLogin {
     fn add(&mut self, proc: &ProcessInfo) {
         let fmt_content = if let Ok(uid) = proc.curr_proc.loginuid() {
-            if let Some(user) = users::get_user_by_uid(uid) {
+            if let Some(user) = USERS_CACHE.with(|x| x.borrow_mut().get_user_by_uid(uid)) {
                 format!("{}", user.name().to_string_lossy())
             } else if uid == UID_NOT_SET {
                 String::new()
