@@ -1,7 +1,9 @@
 use crate::process::ProcessInfo;
+use crate::util::USERS_CACHE;
 use crate::{column_default, Column};
 use std::cmp;
 use std::collections::HashMap;
+use uzers::Users;
 
 pub struct UserReal {
     header: String,
@@ -30,7 +32,7 @@ impl Column for UserReal {
     fn add(&mut self, proc: &ProcessInfo) {
         let fmt_content = if let Some(ref status) = proc.curr_status {
             let uid = status.ruid;
-            if let Some(user) = users::get_user_by_uid(uid) {
+            if let Some(user) = USERS_CACHE.with(|x| x.borrow_mut().get_user_by_uid(uid)) {
                 format!("{}", user.name().to_string_lossy())
             } else {
                 format!("{uid}")
@@ -47,16 +49,35 @@ impl Column for UserReal {
     column_default!(String);
 }
 
-#[cfg_attr(tarpaulin, skip)]
 #[cfg(target_os = "macos")]
 impl Column for UserReal {
     fn add(&mut self, proc: &ProcessInfo) {
         let uid = proc.curr_task.pbsd.pbi_ruid;
-        let fmt_content = if let Some(user) = users::get_user_by_uid(uid) {
-            format!("{}", user.name().to_string_lossy())
-        } else {
-            format!("{}", uid)
-        };
+        let fmt_content =
+            if let Some(user) = USERS_CACHE.with(|x| x.borrow_mut().get_user_by_uid(uid)) {
+                format!("{}", user.name().to_string_lossy())
+            } else {
+                format!("{}", uid)
+            };
+        let raw_content = fmt_content.clone();
+
+        self.fmt_contents.insert(proc.pid, fmt_content);
+        self.raw_contents.insert(proc.pid, raw_content);
+    }
+
+    column_default!(String);
+}
+
+#[cfg(target_os = "freebsd")]
+impl Column for UserReal {
+    fn add(&mut self, proc: &ProcessInfo) {
+        let uid = proc.curr_proc.info.ruid;
+        let fmt_content =
+            if let Some(user) = USERS_CACHE.with(|x| x.borrow_mut().get_user_by_uid(uid)) {
+                format!("{}", user.name().to_string_lossy())
+            } else {
+                format!("{}", uid)
+            };
         let raw_content = fmt_content.clone();
 
         self.fmt_contents.insert(proc.pid, fmt_content);
