@@ -34,10 +34,10 @@ impl Column for VmSwap {
                 let val = val.saturating_mul(1024);
                 (val, bytify(val))
             } else {
-                (0, String::from(""))
+                (0, String::new())
             }
         } else {
-            (0, String::from(""))
+            (0, String::new())
         };
 
         self.fmt_contents.insert(proc.pid, fmt_content);
@@ -47,7 +47,6 @@ impl Column for VmSwap {
     column_default!(u64);
 }
 
-#[cfg_attr(tarpaulin, skip)]
 #[cfg(target_os = "windows")]
 impl Column for VmSwap {
     fn add(&mut self, proc: &ProcessInfo) {
