@@ -15,7 +15,8 @@ use crate::util::{adjust, get_theme, lap, ArgColorMode, ArgPagerMode, ArgThemeMo
 use crate::view::View;
 use crate::watcher::Watcher;
 use anyhow::{anyhow, Context, Error};
-use clap::{ArgEnum, IntoApp, Parser};
+use clap::builder::styling::{AnsiColor, Effects, Styles};
+use clap::{CommandFactory, Parser, ValueEnum};
 use clap_complete::Shell;
 use console::Term;
 use std::cmp;
@@ -30,7 +31,7 @@ use unicode_width::UnicodeWidthStr;
 // Opt
 // ---------------------------------------------------------------------------------------------------------------------
 
-#[derive(Clone, Debug, ArgEnum)]
+#[derive(Clone, Debug, ValueEnum)]
 pub enum BuiltinConfig {
     Default,
     Large,
@@ -38,7 +39,14 @@ pub enum BuiltinConfig {
 
 #[derive(Debug, Parser)]
 #[clap(long_version(option_env!("LONG_VERSION").unwrap_or(env!("CARGO_PKG_VERSION"))))]
-#[clap(setting(clap::AppSettings::DeriveDisplayOrder))]
+#[clap(
+    styles(Styles::styled()
+        .header(AnsiColor::Yellow.on_default() | Effects::BOLD)
+        .usage(AnsiColor::Yellow.on_default() | Effects::BOLD)
+        .literal(AnsiColor::Green.on_default() | Effects::BOLD)
+        .placeholder(AnsiColor::Cyan.on_default())
+    )
+)]
 /// A modern replacement for ps
 ///
 /// please see https://github.com/dalance/procs#configuration to configure columns
@@ -49,7 +57,6 @@ pub struct Opt {
 
     /// AND  logic for multi-keyword
     #[clap(
-        action,
         short = 'a',
         long = "and",
         conflicts_with_all(&["or", "nand", "nor"])
@@ -58,7 +65,6 @@ pub struct Opt {
 
     /// OR   logic for multi-keyword
     #[clap(
-        action,
         short = 'o',
         long = "or",
         conflicts_with_all(&["and", "nand", "nor"])
@@ -67,7 +73,6 @@ pub struct Opt {
 
     /// NAND logic for multi-keyword
     #[clap(
-        action,
         short = 'd',
         long = "nand",
         conflicts_with_all(&["and", "or", "nor"])
@@ -76,7 +81,6 @@ pub struct Opt {
 
     /// NOR  logic for multi-keyword
     #[clap(
-        action,
         short = 'r',
         long = "nor",
         conflicts_with_all(&["and", "or", "nand"])
@@ -84,45 +88,38 @@ pub struct Opt {
     pub nor: bool,
 
     /// Show list of kind
-    #[clap(action, short = 'l', long = "list")]
+    #[clap(short = 'l', long = "list")]
     pub list: bool,
 
     /// Show thread
-    #[clap(action, long = "thread")]
+    #[clap(long = "thread")]
     pub thread: bool,
 
     /// Tree view
-    #[clap(action, short = 't', long = "tree")]
+    #[clap(short = 't', long = "tree")]
     pub tree: bool,
 
     /// Watch mode with default interval (1s)
-    #[clap(action, short = 'w', long = "watch")]
+    #[clap(short = 'w', long = "watch")]
     pub watch: bool,
 
     /// Watch mode with custom interval
-    #[clap(action, short = 'W', long = "watch-interval", value_name = "second")]
+    #[clap(short = 'W', long = "watch-interval", value_name = "second")]
     pub watch_interval: Option<f64>,
 
     #[clap(skip)]
     pub watch_mode: bool,
 
     /// Insert column to slot
-    #[clap(
-        action,
-        value_name = "kind",
-        short = 'i',
-        long = "insert",
-        number_of_values(1)
-    )]
+    #[clap(value_name = "kind", short = 'i', long = "insert", number_of_values(1))]
     pub insert: Vec<String>,
 
     /// Specified column only
-    #[clap(action, value_name = "kind", long = "only")]
+    #[clap(value_name = "kind", long = "only")]
     pub only: Option<String>,
 
     /// Sort column by ascending
     #[clap(
-        action,
         value_name = "kind",
         long = "sorta",
         conflicts_with_all(&["sortd", "tree"])
@@ -131,7 +128,6 @@ pub struct Opt {
 
     /// Sort column by descending
     #[clap(
-        action,
         value_name = "kind",
         long = "sortd",
         conflicts_with_all(&["sorta", "tree"])
@@ -139,52 +135,47 @@ pub struct Opt {
     pub sortd: Option<String>,
 
     /// Color mode
-    #[clap(action, short = 'c', long = "color")]
+    #[clap(short = 'c', long = "color")]
     pub color: Option<ArgColorMode>,
 
     /// Theme mode
-    #[clap(action, long = "theme")]
+    #[clap(long = "theme")]
     pub theme: Option<ArgThemeMode>,
 
     /// Pager mode
-    #[clap(action, short = 'p', long = "pager")]
+    #[clap(short = 'p', long = "pager")]
     pub pager: Option<ArgPagerMode>,
 
     /// Interval to calculate throughput
-    #[clap(
-        action,
-        long = "interval",
-        default_value = "100",
-        value_name = "millisec"
-    )]
+    #[clap(long = "interval", default_value = "100", value_name = "millisec")]
     pub interval: u64,
 
     /// Use built-in configuration
-    #[clap(action, long = "use-config", value_name = "name")]
+    #[clap(long = "use-config", value_name = "name")]
     pub use_config: Option<BuiltinConfig>,
 
     /// Load configuration from file
-    #[clap(action, long = "load-config", value_name = "path")]
+    #[clap(long = "load-config", value_name = "path")]
     pub load_config: Option<PathBuf>,
 
     /// Generate configuration sample file
-    #[clap(action, long = "gen-config")]
+    #[clap(long = "gen-config")]
     pub gen_config: bool,
 
     /// Generate shell completion file
-    #[clap(action, long = "gen-completion", value_name = "shell")]
+    #[clap(long = "gen-completion", value_name = "shell")]
     pub gen_completion: Option<Shell>,
 
     /// Generate shell completion file and write to stdout
-    #[clap(action, long = "gen-completion-out", value_name = "shell")]
+    #[clap(long = "gen-completion-out", value_name = "shell")]
     pub gen_completion_out: Option<Shell>,
 
     /// Suppress header
-    #[clap(action, long = "no-header")]
+    #[clap(long = "no-header")]
     pub no_header: bool,
 
     /// Show debug message
-    #[clap(action, long = "debug", hide = true)]
+    #[clap(long = "debug", hide = true)]
     pub debug: bool,
 }
 
@@ -192,7 +183,6 @@ pub struct Opt {
 // Functions
 // ---------------------------------------------------------------------------------------------------------------------
 
-#[cfg_attr(tarpaulin, skip)]
 fn get_config(opt: &Opt) -> Result<Config, Error> {
     let dot_cfg_path = directories::BaseDirs::new()
         .map(|base| base.home_dir().join(".procs.toml"))
@@ -255,7 +245,6 @@ fn check_old_config(s: &str, config: Result<Config, toml::de::Error>) -> Result<
 // Main
 // ---------------------------------------------------------------------------------------------------------------------
 
-#[cfg_attr(tarpaulin, skip)]
 fn main() {
     let err = Term::stderr();
 
@@ -275,7 +264,6 @@ fn main() {
     }
 }
 
-#[cfg_attr(tarpaulin, skip)]
 fn run() -> Result<(), Error> {
     let mut opt: Opt = Parser::parse();
     opt.watch_mode = opt.watch || opt.watch_interval.is_some();
@@ -344,7 +332,6 @@ fn run_list() -> Result<(), Error> {
     Ok(())
 }
 
-#[cfg_attr(tarpaulin, skip)]
 fn run_watch(opt: &mut Opt, config: &Config, interval: u64) -> Result<(), Error> {
     Watcher::start(opt, config, interval)
 }
